bayespy.nodes.VaryingGaussianMarkovChain.get_riemannian_gradient
================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: VaryingGaussianMarkovChain.get_riemannian_gradient